@@ -171,15 +171,21 @@ class Select {
      *
      * @throws HsqlException
      */
-    void resolveTables() throws HsqlException {
+    private void resolveTables() throws HsqlException {
 
         // replace the aliases with expressions
         for (int i = iResultLen; i < exprColumns.length; i++) {
             if (exprColumns[i].exprType == Expression.COLUMN) {
                 if (exprColumns[i].joinedTableColumnIndex == -1) {
+                    boolean descending = exprColumns[i].isDescending();
+
                     exprColumns[i] =
                         exprColumns[i].getExpressionForAlias(exprColumns,
                             iResultLen);
+
+                    if (descending) {
+                        exprColumns[i].setDescending();
+                    }
                 }
             } else {
                 exprColumns[i].replaceAliases(exprColumns, iResultLen);
@@ -215,6 +221,17 @@ class Select {
         }
     }
 
+    void resolveTablesUnion(TableFilter f) throws HsqlException {
+
+        if (unionArray == null) {
+            resolveTables(f);
+        } else {
+            for (int i = 0; i < unionArray.length; i++) {
+                unionArray[i].resolveTables(f);
+            }
+        }
+    }
+
     /**
      * Resolves the tables for all the Expression in the Select object
      * if it is possible to do so with the given TableFilter.
@@ -301,7 +318,7 @@ class Select {
 */
 
     /**
-     * Retruns a single value result or throws if the result has more than
+     * Returns a single value result or throws if the result has more than
      * one row with one value.
      *
      * @param type data type
@@ -338,8 +355,7 @@ class Select {
     }
 
     /**
-     * Prepares rResult having structure compatible with
-     * internally building the set of rows returned from getResult().
+     * Resolves expressions and pepares thre metadata for the result.
      */
     void prepareResult(Session session) throws HsqlException {
 
@@ -350,7 +366,12 @@ class Select {
             groupColumnNames = new HashSet();
 
             for (int i = iResultLen; i < iResultLen + iGroupLen; i++) {
-                exprColumns[i].collectColumnName(groupColumnNames);
+
+//              MarcH: this is wrong for a CASE WHEN statement in a SELECT CASE WHEN ...,<something aggregate> statement
+//              collectColumnName collects no columns if exprColumns[i]'s expressiontype is Expression.CASEWHEN
+//              collectAllColumnNames collects all columns used in the CASE WHEN statement
+//              exprColumns[i].collectColumnName(groupColumnNames);
+                exprColumns[i].collectAllColumnNames(groupColumnNames);
             }
         }
 
@@ -464,7 +485,7 @@ class Select {
 
         Result r;
 
-        if (unionType == NOUNION) {
+        if (unionArray == null) {
             r = getSingleResult(session, maxrows);
         } else {
             r = getResultMain(session);
